@@ -2,10 +2,11 @@ package org.gcube.portlets.widgets.wsmail.client.multisuggests;
 
 import java.util.ArrayList;
 
-import org.gcube.portlets.widgets.sessionchecker.client.CheckSession;
+
 import org.gcube.portlets.widgets.wsmail.client.WsMailService;
 import org.gcube.portlets.widgets.wsmail.client.WsMailServiceAsync;
 import org.gcube.portlets.widgets.wsmail.client.events.RenderForm;
+import org.gcube.portlets.widgets.wsmail.server.WsMailServiceImpl;
 import org.gcube.portlets.widgets.wsmail.shared.CurrUserAndPortalUsersWrapper;
 import org.gcube.portlets.widgets.wsmail.shared.WSUser;
 
@@ -55,6 +56,7 @@ public class MultiValuePanel extends Composite {
 		list.setStyleName("multivalue-panel-list");
 		final ListItem item = new ListItem();
 		final TextBox itemBox = new TextBox();
+		itemBox.getElement().setAttribute("autocomplete", "off");
 		itemBox.getElement().setAttribute("style", "outline-color: -moz-use-text-color; outline-style: none; outline-width: medium; border: none;");
 		box = new SuggestBox(getSuggestions(), itemBox);
 
@@ -115,9 +117,11 @@ public class MultiValuePanel extends Composite {
 			//original value of the item selected
 			GWT.log("Adding selected item '" + itemBox.getValue());
 			itemsSelected.add(itemBox.getValue());
-			GWT.log("Total: " + itemsSelected);
+			//GWT.log("Total: " + itemsSelected + " count="+list.getWidgetCount());
 
-			list.insert(displayItem, list.getWidgetCount() - 1);
+			int insertionPoint = (list.getWidgetCount() < 1) ? 0 : list.getWidgetCount()-1;
+			
+			list.insert(displayItem, insertionPoint);
 			itemBox.setValue("");
 			itemBox.setFocus(true);			
 		}
@@ -154,7 +158,6 @@ public class MultiValuePanel extends Composite {
 		for (int i = 0; i < fullNames.size(); i++) {
 			String fullName = fullNames.get(i);
 			if (fullName != null) {
-				final ListItem item = new ListItem();
 				final TextBox itemBox = new TextBox();
 				itemBox.getElement().setAttribute("style", "outline-color: -moz-use-text-color; outline-style: none; outline-width: medium; border: none;");
 
@@ -212,9 +215,8 @@ public class MultiValuePanel extends Composite {
 		mailingService.getWorkspaceUsers(new AsyncCallback<CurrUserAndPortalUsersWrapper>() {
 
 			@Override
-			public void onSuccess(CurrUserAndPortalUsersWrapper result) {
-				GWT.log("oh");
-				if (result.getCurrentUser().getScreenname().compareTo("test.user") == 0) {
+			public void onSuccess(CurrUserAndPortalUsersWrapper result) {				
+				if (result.getCurrentUser().getScreenname().compareTo(WsMailServiceImpl.TEST_USER) == 0) {
 					doShowSessionExpired();
 					eventBus.fireEvent(new RenderForm(false));
 				} else{
@@ -224,7 +226,7 @@ public class MultiValuePanel extends Composite {
 						oracle.add(wsUser.getFullName());
 					}				
 					users = result.getUsers();
-					GWT.log("doh");
+					GWT.log("doh"+(eventBus==null));
 					eventBus.fireEvent(new RenderForm(true));
 				}
 			}
@@ -251,14 +253,15 @@ public class MultiValuePanel extends Composite {
 	}
 
 	private void doShowSessionExpired() {
-		GWT.runAsync(new RunAsyncCallback() {
-			@Override
-			public void onSuccess() {
-				CheckSession.showLogoutDialog();
-			}
-			public void onFailure(Throwable reason) {
-				Window.alert("Could not load this component: " + reason.getMessage());
-			}   
-		});
+		Window.alert("Session Expired, logout please");
+//		GWT.runAsync(new RunAsyncCallback() {
+//			@Override
+//			public void onSuccess() {
+//				CheckSession.showLogoutDialog();
+//			}
+//			public void onFailure(Throwable reason) {
+//				Window.alert("Could not load this component: " + reason.getMessage());
+//			}   
+//		});
 	}
 }
